@@ -22,9 +22,10 @@ def default(val, d):
 def max_neg_value(t):
     return -torch.finfo(t.dtype).max
 
-def stable_softmax(t, dim = -1):
+def stable_softmax(t, dim = -1, alpha = 32 ** 2):
+    t = t / alpha
     t = t - torch.amax(t, dim = dim, keepdim = True)
-    return t.softmax(dim = dim)
+    return (t * alpha).softmax(dim = dim)
 
 # classes
 
